"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLicensePackageInfo = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _access = require("../../../cmd/access");

var _execReturn = require("../../../cmd/execReturn");

var _readFile = require("../../../cmd/readFile");

var _getLicenseFromFiles = require("./getLicenseFromFiles");

const getLicensePackageInfo = async ({
  cwd,
  log
}, {
  path,
  ignorePackages,
  licenseAliases,
  licenseHeuristics
}) => {
  const packageJsonPath = (0, _path.join)(path, 'package.json');
  const hasPackageJson = await (0, _access.access)(packageJsonPath);

  if (!hasPackageJson) {
    return undefined;
  }

  const {
    name,
    license,
    version
  } = await (0, _readFile.readFile)(packageJsonPath, true);

  if (typeof name !== 'string') {
    throw new TypeError(`Package name is not defined (${packageJsonPath})`);
  }

  if (ignorePackages.includes(name)) {
    return undefined;
  }

  const data = {
    path: path.slice(Math.max(0, cwd.length + 1)),
    version: (0, _toolLib.isString)(version) ? version : 'UNKNOWN',
    license: 'UNKNOWN',
    name
  };
  const licensePackage = licenseAliases[data.name];

  if ((0, _toolLib.isObject)(licensePackage) && (0, _toolLib.isString)(licensePackage[data.version])) {
    return { ...data,
      license: licensePackage[data.version]
    };
  }

  if ((0, _toolLib.isString)(license)) {
    return { ...data,
      license
    };
  }

  if ((0, _toolLib.isObject)(license) && (0, _toolLib.isString)(license.type)) {
    return { ...data,
      license: license.type
    };
  }

  const fileLicense = await (0, _getLicenseFromFiles.getLicenseFromFiles)({
    path,
    data,
    licenseHeuristics
  });

  if (fileLicense) {
    return fileLicense;
  }

  const {
    stdout: npmViewLicense
  } = await (0, _execReturn.execReturn)({
    cmd: 'npm',
    args: ['view', name, 'license'],
    log,
    cwd
  });

  if (npmViewLicense.trim() !== '') {
    return { ...data,
      license: npmViewLicense.trim()
    };
  }

  return data;
};

exports.getLicensePackageInfo = getLicensePackageInfo;