"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tscAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _execReturn = require("../../cmd/execReturn");

var _getTypescriptConfigPath = require("../../utils/getTypescriptConfigPath");

const tscAction = async ({
  root,
  cwd,
  log
}, {
  mode
}) => {
  const configPath = await (0, _getTypescriptConfigPath.getTypescriptConfigPath)(cwd, mode);
  const cmd = (0, _path.join)(root, _actionConfigs.typescriptCommand);
  const args = [];

  switch (mode) {
    case 'type-check':
      args.push('--outDir', (0, _path.join)(cwd, 'build'));
      args.push('--project', configPath);
      args.push('--noEmit');
      args.push('--isolatedModules', 'false');
      break;

    case 'type-create':
      args.push('--outDir', (0, _path.join)(cwd, 'build'));
      args.push('--project', configPath);
      args.push('--noEmit', 'false');
      args.push('--emitDeclarationOnly');
      break;

    default:
      throw new Error(`Mode is unknown: ${String(mode)}`);
  }

  log.info('Run TypeScript');
  await (0, _execReturn.execReturn)({
    cmd,
    args,
    cwd,
    log
  });
};

exports.tscAction = tscAction;