"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.depsTask = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _depcheck = require("../actions/tools/depcheck");

var _semver = require("../actions/tools/semver");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _dependencyError = require("../errors/dependencyError");

var _dependencyWarn = require("../errors/dependencyWarn");

var _taskHook = require("../utils/taskHook");

const depsTask = async argv => {
  const configIgnorePackages = await (0, _config.getConfig)(argv.root, 'deps.ignore.packages');
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const ignorePackages = (0, _toolLib.isArray)(configIgnorePackages) ? configIgnorePackages.filter(_toolLib.isString) : [];
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'pre'
  });
  await [argv.root, ...workspacePaths].reduce((promise, path) => promise.then(async () => {
    try {
      const subTitle = path === argv.root ? '' : `[${(0, _path.basename)(path)}]`;
      await (0, _spinner.spinnerAction)((0, _depcheck.depcheckAction)(argv, {
        path,
        ignorePackages
      }), `Dependency verification ${subTitle}`);
    } catch (error) {
      if (error instanceof _dependencyError.DependencyError) {
        argv.log.log(error.list);
        throw error;
      }

      if (!(error instanceof _dependencyWarn.DependencyWarn)) {
        throw error;
      }

      argv.log.log(error.list);
    }
  }), Promise.resolve());
  await (0, _spinner.spinnerAction)((0, _semver.semverAction)(argv, {}), 'Semver check');
  await workspacePaths.reduce((promise, path) => promise.then(() => (0, _spinner.spinnerAction)((0, _semver.semverAction)(argv, {
    path
  }), `Semver check [${(0, _path.basename)(path)}]`)), Promise.resolve());
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'post'
  });
};

exports.depsTask = depsTask;